from setuptools import setup

setup(name='sv_practise_distributions',
      version='0.1',
      description='Gaussian & Binomial distributions',
      packages=['sv_practise_distributions'],
      zip_safe=False)
